# FAQ

## 版本号为什么是 2.0

因为 yutto 是 [bilili](https://github.com/yutto-dev/bilili) 的後輩呀～

## 名字的由来

[《転スラ日記》第一话 00:24](https://www.bilibili.com/bangumi/play/ep395211?t=24)

## 何谓「任性」？

我不一定会满足你的所有需求哦，从设计者的角度，为我添加任何特性都需要以保证可维护性为前提，因此我不会支持过于复杂的特性，只需要满足大多数用户的需求即可～

## yutto 会替代 bilili 吗

我自诞生以来已经过去三年多了，功能上基本可以替代 bilili 了，由于 B 站接口的不断变化，bilili 也不再适用于现在的环境，因此请 bilili 用户尽快迁移到 yutto ～
